#
# spec file for package python-pbr
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-pbr%{psuffix}
Version:        6.1.1
Release:        2.1
Summary:        Python Build Reasonableness
License:        Apache-2.0
URL:            https://docs.openstack.org/pbr/latest/
Source:         https://files.pythonhosted.org/packages/source/p/pbr/pbr-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-setuptools >= 64.0.0
Recommends:     git-core
Obsoletes:      python-pbr-doc
BuildArch:      noarch
%if %{with test}
# Package originates from OpenStack and depends on other OpenStack packages for testing.
# These are only available for the primary python3 interpreter in TW, but optional.
# --> Only test in default python3 flavor.  gh#openSUSE/python-rpm-macros#66
# Python 2 packages on Leap are too outdated to test, either (stestr, subunit).
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module fixtures >= 3.0.0}
BuildRequires:  %{python_module pbr = %{version}}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six >= 1.12.0}
BuildRequires:  %{python_module testresources >= 2.0.0}
BuildRequires:  %{python_module testscenarios >= 0.4}
BuildRequires:  %{python_module testtools >= 2.2.0}
BuildRequires:  %{python_module virtualenv >= 20.0.3}
BuildRequires:  %{python_module wheel >= 0.32.0}
BuildRequires:  git-core
BuildRequires:  gpg2
%endif
%python_subpackages

%description
PBR is a library to automatically do a bunch of standard
things you want in your setup.py without you having to repeat
them every time. It will set versions, process requirements
files and generate AUTHORS and ChangeLog file all from git
information.

%prep
%autosetup -p1 -n pbr-%{version}

sed -i '/coverage/d;/hacking/d' test-requirements.txt

%build
%pyproject_wheel

%if %{with test}
%check
export OS_TEST_TIMEOUT=60
exclude="parse_requirements|requirement_parsing|pep_517_support|"
exclude+="write_git_changelog|build_doc|cmd_builder_override|"
exclude+="extras_parsing|project_url_parsing|keywords_parsing|"
exclude+="test_handling_of_whitespace_in_data_files"
# Run tests with pytest to do not depend on python-stestr, that's no
# available on SLFO:Main
# stestr run -E "($exclude)"
%pytest -k "not (${exclude//|/ or })"
%endif

%if !%{with test}
%install
%pyproject_install
%python_expand rm -r  %{buildroot}%{$python_sitelib}/pbr/tests
%python_clone -a %{buildroot}%{_bindir}/pbr

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%pre
%python_libalternatives_reset_alternative pbr

%files %{python_files}
%license LICENSE
%doc AUTHORS ChangeLog CONTRIBUTING.rst README.rst
%python_alternative %{_bindir}/pbr
%{python_sitelib}/pbr
%{python_sitelib}/pbr-%{version}.dist-info
%endif

%changelog
* Thu Jul 17 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Wed Feb 12 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 6.1.1
  * docs: Drop SetupTools from pyproject.toml example
  * Simplify PBR dependency on SetupTools
  * Update setup.cfg example in Usage document
  * Clarify PEP 517 implementation for users
- from version 6.1.1.0b1
  * Set up PBR with setuptools as a dependency
  * Use pyproject.toml
  * Test pip and setup.py install behavior in PBR testing
  * Remove the use of six from PBR
  * Fix integration testing of current change
  * Update PBR testing for Noble
* Mon Oct 28 2024 Daniel Garcia <daniel.garcia@suse.com>
- Use pytest to run tests to do not depend on python-stestr
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 6.1.0:
  * Add openstack-tox-py312 as non-voting job
  * Add SetupTools to our functional testing venvs
  * Use SetupTools' vendored distutils in tests
  * Also run coverage tests serially
  * Omnibus PBR CI fixups
  * Serialize tests
  * Fix tempest-full job
  * Use summary for the package summary
  * Test on py310 and py311
* Mon May 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Use stestr rather than pytest to run the testsuite.
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * build: Use kwargs
  * Add support for PEP-660
  * Fix PBR integration testing
  * Replace imp with importlib.machinery
  * Add release note for build\_sphinx removal
  * Use \_ instead of - in setup.cfg directives
  * Remove sphinx doc building integration
* Thu May  4 2023 Martin Liška <mliska@suse.cz>
- Support Sphinx 7.0 by skipping of some tests that depend
  on legacy features (boo#1211051).
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Apr 18 2023 Matej Cepl <mcepl@suse.com>
- Switch to single spec version build for PSP
* Fri Apr 14 2023 Matej Cepl <mcepl@suse.com>
- Switch to single spec version build for PSP
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Apr  4 2023 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on pep517.
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 5.11.1:
  * Run PBR integration on Ubuntu Focal too
  * Remove numpy dependencies
  * Tie recursion calls to Dist object, not module
  * Update tox.ini to work with tox 4
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 5.11.0
  * Fix symbol identification in multiline message
  * Replace deprecated readfp method with read_file
* Fri Aug 19 2022 Dirk Müller <dmueller@suse.com>
- update to 5.10.0:
  * Specify Changelog procedure
  * Allow leading spaces when determining symbols
  * Adding python classifiers py38 & py39
* Wed Aug 10 2022 Dirk Müller <dmueller@suse.com>
- update to 5.9.0:
  * Future-proofing pyproject.toml
  * Use importlib-metadata for runtime package version lookups
  * Drop wheel from pyproject.toml examples
  * Changed minversion in tox to 3.18.0
* Tue Feb 22 2022 Dirk Müller <dmueller@suse.com>
- update to 5.8.1:
  * Add release note about missing pbr.json fix
  * Avoid recursive calls into SetupTools entrypoint
  * remove explicit mock
  * Don't test with setuptools local distutils
  * Use context blocks for open() calls in packaging
- remove remove_mock.patch (upstream)
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 5.8.0:
  * Add python2 testing back to PBR
  * Allow PEP517 without setup\_requires
  * Clarify the need for setup.py with PEP517
* Sat Nov  6 2021 Dirk Müller <dmueller@suse.com>
- update to 5.7.0:
  * Add a PEP517 interface
  * PBR package testing improvements
  * Run python3.9 test jobs
  * Correct comment for 'D1\_D2\_SETUP\_ARGS'
* Tue May 18 2021 Dirk Müller <dmueller@suse.com>
- update to 5.6.0:
  * Reverse ordering of 'D1\_D2\_SETUP\_ARGS'
  * Add test for cfg -> py transformation
  * Don't pass empty 'long\_description'
  * Move flake8 as a pre-commit local target
  * Map requires-python to python-requires (attempt 2)
  * Update dependencies to avoid failure with old pip
  * Increase OS\_TEST\_TIMEOUT to 1200
  * Prevent test failure due to use of setpref
  * util: Convert 'D1\_D2\_SETUP\_ARGS' to a list of tuples
  * Revert "Map requires-python to python-requires"
  * Dropping lower constraints testing
  * Adding pre-commit
* Sat Dec 19 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 5.5.1
  * Run tempest-full for stable/train
  * Remove use_2to3 backward compat for Setuptools
  * More easy_install.ScriptWriter.get_header()
- Changes for 5.5.0
  * Remove bdist_wininst support
  * Increase integration test timeout
  * Add Release Notes to documentation
  * Cleanup old legacy devstack-gate jobs
  * Begin work to modernize pbr’s integration testing
  * Re-add ChangeLog
  * Update some url to use opendev.org
  * Support newer openstackdocstheme
  * Use easy_install.ScriptWriter.get_header()
  * Remove neutron-fwaas from the jobs’ required project
  * Update python requires packaging metadata for package
  * trivial: Improve logging of run commands
  + Map requires-python to python-requires
  * Update hacking
  * Add support for virtualenv 20.x
- Only test the primary python3 interpreter because some test
  dependencies from OpenStack (which are not hard required by the
  package itself) only provide that one.
  gh#openSUSE/python-rpm-macros#66
- Add remove_mock.patch
  https://review.opendev.org/c/openstack/pbr/+/767972
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.4.5:
  * Switch to Ussuri jobs
* Thu Mar 19 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip temporarily test_requirement_parsing as it requires
  old virtualenv 16 package, the 20.x changed api and the tests
  infrastructure would need rewrite
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.4.4:
  * trivial: Use 'open' context manager
  * Update to latest hacking
  * Mark strings as raw
* Fri Oct 18 2019 Dirk Mueller <dmueller@suse.com>
- update to 5.4.3
  * Use more verbose logging for test failure
* Thu Oct 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove buildignores on pyparsing as the cycle is now sorted
* Thu Aug  8 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 5.4.2:
  * Add Python 3 Train unit tests
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.4.1:
  * Various fixes
* Tue Jun 18 2019 pgajdos@suse.com
- version update to 5.3.0
  * Stop using pbr sphinx integration
  * Switch to release.o.o for constraints
  * Make WSGI tests listen on localhost
  * Allow git-tags to be SemVer compliant
  * Read description file as utf-8
* Wed May 15 2019 Jonathan Harker <jharker@suse.com>
- Update to 5.2.0
  * Support provides_extra metadata
  * Remove libzmq-dev from integration.sh package install
  * Fix error when keywords are defined as a list in cfg
* Mon May 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not generate any packages in the test multibuild run
* Tue Mar 26 2019 John Vandenberg <jayvdb@gmail.com>
- Add Recomends for git-core and python-reno
- Add Suggests for python-Sphinx and python-nose
- Increase minimum dependency versions to match upstream
- Add build dependency pip, pyparsing, reno and testrepository
  used by the test suite
- Remove unnecessary test dependencies coverage and hacking
- Use OS_TEST_TIMEOUT=60 in %%check to fix sparodic failing tests
  due to timeouts with the default 30 seconds
- Remove no longer needed steps in %%prep due to upstream changes
- Replace build dependency git with smaller git-core
* Fri Mar  1 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 5.1.3
- drop 0001-Skip-test-for-testr-hook-being-installed-when-testr-.patch
    new_wheel.patch
  * Resolve ``ValueError`` when mapping value contains a literal ``=``
  * ignore –find-links in requirements file
  * Do not globally replace path prefix
  * Use templates for cover and lower-constraints
  * Special case long_description_content_type
  * Support wheel 0.32.0+
* Thu Jan 17 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildIgnore python[23]-pyparsing: python-packaging requires it
  for some actions it could perform, but we don't make use of these
  here. Ignoring this dependency allows us to break open a
  BuildCycle.
* Tue Dec 11 2018 Matěj Cepl <mcepl@suse.com>
- Actually, although the package is noarch, its test suite is not, so we
  need python-devel at least for tests.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Nov  7 2018 mmnelemane@suse.com
- Fix for error "invalid option --#" in SLE_12_SP4 build.
* Mon Oct 15 2018 Matej Cepl <mcepl@suse.com>
- Update to 4.3.0:
  * Remove my\_ip from generated wsgi script
  * Fix typo in contribution instructions
  * Add release note for fix to bug 1786306
  * Move pbr-installation jobs in-tree
  * Support subdirectory in the url
  * remove pypy jobs
  * add lib-forward-testing-python3 test job
  * add python 3.6 unit test job
  * switch documentation job to new PTI
  * import zuul job settings from project-config
  * Ignore Zuul when generating AUTHORS
  * tox: Re-add cover target
- Add new_wheel.patch to make compatible with wheel = 0.32.1
* Sun Oct  7 2018 mcepl@suse.com
- Revert previous commit.
* Sun Oct  7 2018 Matěj Cepl <mcepl@suse.com>
- Partially switch off tests requiring testscenarios and stestr.
* Fri Sep 14 2018 dmueller@suse.com
- add 0001-Skip-test-for-testr-hook-being-installed-when-testr-.patch
* Tue Sep  4 2018 dmueller@suse.com
- update to 4.2.0:
  * Deprecate 'test' integration
  * Deprecate 'build\_sphinx' integration
  * Add Sphinx extension
  * doc: Add documentation for missing '[pbr]' options
  * doc: Fix formatting of packagers guide
  * Switch to stestr
* Mon Aug 27 2018 tchvatal@suse.com
- Move the Name declaration above BR with LUA expansion as it won't
  get expanded in time for older codestreams otherwise and result
  in issue like "Package does not exist: %%files -n python-%%name"
* Wed Aug 15 2018 mcepl@suse.com
- Fix conditions when to enanle tests and when not.
* Mon Aug  6 2018 tchvatal@suse.com
- Switch to multibuild to run tests
- Drop doc subpkg, they have compiled docu on web, much better
  * Drops patch for_sphinx.patch
* Mon Aug  6 2018 tchvatal@suse.com
- Version update to 4.1.1:
  * Fixes on python 3.x
* Fri May 25 2018 mimi.vx@gmail.com
- for_sphinx.patch - allow warnings for sphinx_build
  unfortuanetly python3 and python2 Sphinx have diff in docstring parsing
* Wed May 23 2018 arun@gmx.de
- update to version 4.0.3:
  * Don't poke in pip for requests
  * Fix builddoc with sphinx <= 1.6
* Mon Apr 23 2018 arun@gmx.de
- update to version 4.0.2:
  * Better Sem-Ver header handling
- changes from version 4.0.1:
  * add lower-constraints job
  * Explicitly read setup.cfg as utf-8 on Python 3
* Wed Mar 28 2018 tbechtold@suse.com
- update to 4.0.0:
  * builddoc: Treat '[pbr] autodoc\_tree\_excludes' as a multi-line opt
  * update parse test to use reliable comparison
  * Make docs on env vars a little clearer
  * Updated from global requirements
  * future-proof invocation of apidoc
  * emit warning correctly
  * deprecations: Deprecate support for '-py{N}' requirements
  * doc: Minor rework of usage doc
  * doc: Rework features doc
  * Support v<semver> version
  * Deprecate testr and nose integration
  * tests: Increase coverage of requirements parsing
  * trivial: Move packaging tests to test\_packaging
  * Put test-requirements into an extra named 'test'
  * Support Description-Content-Type metadata
  * Avoid tox\_install.sh for constraints support
  * Test on Python 3.6
  * Support PEP 345 Project-URL metadata
  * Remove setting of version/release from releasenotes
  * Use 'build\_reno' setuptools extension if available
  * Remove unnecessary 'if True'
  * Discover Distribution through the class hierarchy
  * Add reno for release notes management
  * Remove support for command hooks
  * Remove dead code
  * Deprecate support for Sphinx < 1.6
  * builddoc: Use '[sphinx\_build] builders' with Sphinx < 1.6
  * Remove win32/nt checks for wrapper script gen
  * Remove py26 support
  * Update URLs in documents according to document migration
  * gitignore: Ignore .venv
  * switch from oslosphinx to openstackdocstheme
  * Trivial: Fix docstring
  * turn on warning-as-error flag for doc build
  * rearrange existing documentation using the new standard layout
* Mon Oct 30 2017 jmatejek@suse.com
- use %%python_clone instead of manual copying
- drop shebang and executable from the included test setup.py
  instead of complicated post-install fixing
* Tue Aug  8 2017 tbechtold@suse.com
- remove unused BuildRequires on python-pip
- add python-setuptools as BuildRequires
* Mon Jul 10 2017 toddrme2178@gmail.com
- Fix wrong-script-interpreter rpmlint error.
* Thu Jun 29 2017 tbechtold@suse.com
- update to 3.1.1:
  * Restore previous IP binding
  * allow user to override the output location of api docs
  * fix tests based on API change in Sphinx
  * Updated from global requirements
  * Add binding option for WSGI server
  * Ignore index URL lines in requirements.txt files
* Thu May 18 2017 dmueller@suse.com
- Update to pbr-3.0.1:
  * builddoc: uses the new Sphinx 1.6 code for multiple builder
  * Updated from global requirements
  * Fix missing comment from previous change
  * trivial: Add note about multiple builders support
  * Remove 'build\_sphinx\_latex'
  * Stop building man pages by default
  * docs: Use definition lists
  * add image.nonlocal\_uri to the list of warnings ignored
  * doc: Document Sphinx integration
  * add changelog to published documentation
  * Lazy import pkg\_resources
  * Add Changelog build handling for invalid chars
  * Initialize sphinx config using application instead of config
  * Make oslosphinx optional
  * Updated from global requirements
  * Also generate XML coverage report
  * Update to a newer hacking library
- drop 0001-Initialize-sphinx-config-using-application-instead-o.patch
  Upstream
* Mon Apr  3 2017 tbechtold@suse.com
- Add 0001-Initialize-sphinx-config-using-application-instead-o.patch
* Wed Mar 29 2017 jmatejek@suse.com
- uninstall alternatives in %%postun
* Wed Mar 29 2017 tbechtold@suse.com
- Fix Source url
* Wed Mar  8 2017 aplanas@suse.com
- Update to pbr-2.0.0
  * tox: Don't set skipsdist=True
  * Stop using 'warnerrors'
  * doc: Clarify sections in 'setup.cfg'
  * Updated from global requirements
  * Remove discover from test-requirements
  * Add Constraints support
  * Don't raise exception on missing man pages
  * Updated from global requirements
  * Clean imports in code
  * Updated from global requirements
  * Docstrings should not start with a space
  * Changed the home-page link
  * Update .coveragerc after the removal of openstack directory
  * coverage package name option, doc improvement
  * Updated from global requirements
  * Deprecated warning for SafeConfigParser
  * Add more words to a confusing error message
  * Don't ignore data-files
  * Change assertTrue(isinstance()) by optimal assert
  * Fix handling of old git log output
  * Fix typo in the index.rst
  * Expose deb version to match exposing rpm version
  * Replace OpenStack LLC with OpenStack Foundation
  * Updated from global requirements
  * Fix pypy soabi tests
  * Add Python 3.5 classifier and venv
  * Fix argument order for assertEqual to (expected, observed)
  * Move to oslosphinx
  * Updated from global requirements
  * Restore warnerrors behavior and support Sphinx 1.4
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Fix pypy wsgi tests
  * Remember the insertion order for pbr.json
- Remove 0001-Don-t-ignore-data-files.patch (included)
- Remove 0001-Don-t-raise-exception-on-missing-man-pages.patch (included)
* Mon Feb 27 2017 jmatejek@suse.com
- use hardlinks instead of symlinks for %%fdupes, because
  symlinks would point across subpackages
* Tue Feb 21 2017 jmatejek@suse.com
- update for singlespec
* Mon Feb 20 2017 dmueller@suse.com
- add 0001-Don-t-raise-exception-on-missing-man-pages.patch,
  0001-Don-t-ignore-data-files.patch
* Tue Sep 27 2016 tbechtold@suse.com
- Add missing python-setuptools Requires.
* Tue Sep 27 2016 tbechtold@suse.com
- Remove unneeded Requires for python-pip. It's only used
  for testing.
* Tue May 24 2016 tbechtold@suse.com
- Fix pypi source
* Tue May 24 2016 tbechtold@suse.com
- update to 1.10.0:
  * File is wrongly marked as executable
  * Fix wsgiref script use with oslo.config
  * Update Preversioning explanation to avoid double that
  * Handle IndexError during version string parsing
  * Correct server test
  * Updated from global requirements
  * Fix soabi tests with pypy
  * package: fix wrong catch in email parsing
  * Do not convert git tags when searching history
  * Include wsgi_scripts in generated wheels
  * Correct the indentation in the classifiers example
  * Do not silently drop markers that fail to evaluate
  * Clarifications around tags and version numbers
  * Correct typo - s/enabeld/enabled/
  * Use apt-cache generated packages to provide build deps
  * fix some variable names
  * Don't attempt to test with 0.6c11 with Py3
  * Support entry point patching on setuptools < 12
  * Updated from global requirements
  * Split changelog on nulls instead of (
  * Add libjpeg and liberasurecode for tests
  * Handle markers to support sdist on pip < 6
  * Deprecated tox -downloadcache option removed
  * passenv integration environment variables re-enabling integration tests
  * Enable pep8 H405 tests
  * Add patch to properly get all commands from dist
  * doc: Remove 'MANIFEST.in'
  * doc: Trivial cleanup of 'index.rst'
  * doc: Add deprecation note for 'requirements-pyN'
  * doc: Restructure 'Requirements' section
  * doc: Restructure 'Usage' section
  * doc: Add details of manifest generation
  * Support git://, git+ssh://, git+https:// without -e flag
  * More support Sphinx >=1.3b1 and <1.3.1
  * Fix docs for markers
  * Do not error when running pep8 with py3
  * Ensure changelog log output is written if it already exists
  * Cleanup jeepyb and pypi-mirror special casing
- Adjust BuildRequires
* Fri Apr  1 2016 tbechtold@suse.com
- update to 1.8.1:
  * Handle the case where cmd.distribution has no pbr attribute
  * test_integration cleanups
  * Remove redundant testscenarios glue
  * Add standard code coverage configuration file
  * Add shields.io version/downloads links/badges into README.rst
* Sun Sep 20 2015 tbechtold@suse.com
- update to 1.8.0:
  * Strip comments present in setup.cfg
  * Protect WSGI application with a critical section
- Remove 0001-Remove-sphinx_config.init_values-manual-call.patch
  Fixed upstream
* Wed Sep  9 2015 tbechtold@suse.com
- update to 1.7.0:
  * Have pbr egg_info.writer check PBR is enabled
* Wed Aug 26 2015 tbechtold@suse.com
- update to 1.6.0:
  * Strip comments in requirements files
  * Handle git being entirely absent
  * We require the use of setuptools
  * Fix retrieval of commit data and most recent tag
- Remove 0001-Handle-git-being-entirely-absent.patch .
  Applied upstream
* Wed Aug 12 2015 dmueller@suse.com
- add 0001-Handle-git-being-entirely-absent.patch
- revert dependency on git (see comment in the specfile)
* Tue Aug 11 2015 seife+obs@b1-systems.com
- update to version 1.4.0
  * Fix docs for environment markers in extras
  * Export ChangeLog and AUTHORS in install
  * Show how long the git querying takes
  * Add wsgi_scripts support to PBR
  * Updated from global requirements
- requires python-mock >= 1.2
* Mon Aug  3 2015 toddrme2178@gmail.com
- Actually remove documentation requirements
* Mon Aug  3 2015 toddrme2178@gmail.com
- Split documentation into own package to avoid dependency loop
* Mon Jul 27 2015 toddrme2178@gmail.com
- Fix update-alternatives usage.
* Fri Jul 17 2015 tbechtold@suse.com
- update to 1.3.0:
  * Wrap env markers in parens
  * Updated from global requirements
  * Add more documentation around building docs
  * Updated from global requirements
  * Use string for 'OS_TEST_TIMEOUT' default
  * Updated from global requirements
  * This documents the use of comments that work between 2.6, 2.7 and 3.4
- Add 0001-Remove-sphinx_config.init_values-manual-call.patch . Needed
  for newer Sphinx versions.
* Wed Jun 24 2015 dmueller@suse.com
- update to 1.2.0:
  * Strip markers from test requirements
  * Revert "Remove sphinx_config.init_values(
* Tue Jun  9 2015 tbechtold@suse.com
- update to 1.1.0:
  * Fix test case to be runnable with gnupg 2.1
  * More explicit data_files install location docs
  * Move CapturedSubprocess fixture to base
  * Remove sphinx_config.init_values() manual call
  * Updated from global requirements
  * builddoc: allow to use fnmatch-style exclusion for autodoc
  * doc: add some basic doc about pbr doc options
  * Add home-page into sample setup.cfg
  * Make setup.py --help-commands work without testrepository
- Removed 0001-Remove-sphinx_config.init_values-manual-call.patch
  Applied upstream.
* Tue Jun  2 2015 tbechtold@suse.com
- update to 1.0.1:
  * Remove self.pre_run calls in packaging.py
  * Update hacking to 0.10.x series
  * Teach pbr to read extras and env markers
  * Bump integration test timeouts
  * Finish removing invocations of pip
  * Advertise support for Python3.4
  * Issue #1451976: handle commits with non-utf8 text
  * Parallelise integration tests
- Removed pbr-0.10.8-fix-sphinx-init_values.patch . Replaced upstream
  with 0001-Remove-sphinx_config.init_values-manual-call.patch
- Added 0001-Remove-sphinx_config.init_values-manual-call.patch
* Tue May  5 2015 benoit.monin@gmx.fr
- update to version 0.11.0:
  * Issue #1450210: Preversioning rc tag handling
  * Stop testing setup.py easy_install behaviour
  * Test pip install -e of projects
  * Build all the wheels in one pass rather than many
  * Improve integration.sh
  * Honour new test variable PIPVERSION
  * Be safe, don't let friends use RawConfigParser
  * Revert "Support platform-specific requirements files"
  * Reinstate pure-git-hashes-are-illegal test
  * Ignore non-release related tags
  * Test that MANIFEST.in excludes work
  * Fixup semver
  * Better diagnostics on test failure
  * Don't avoid egg-info quite so often
  * Add truncated lincense text
  * "packages" might list multiple directories
  * Support script text override for newer develop
  * Fixes Windows generated scripts headers
  * Update README format to match release notes tool
  * Be more aggressive about building wheels
  * Use a wheelhouse in the integration test
  * Build a wheel when integration testing PBR changes
  * Use unsafe OpenPGP keys for testing
- increase required version of python-hacking for the tests
* Thu Apr 16 2015 hpj@urpla.net
- Update to version 0.10.8
  * Support script text override for newer develop
- Changes from version 0.10.7
  * _get_revno only returns a commit count
- Changes from 0.10.6
  * Integration test PBR commits
- Changes from 0.10.5
  * Move write_pbr_json to avoid issues with nose
- Changes from 0.10.4
  * Properly check for git before getting git dir
  * Use post version signifiers
  * Only import sphinx during hook processing
- Changes from 0.10.3
  * Stop including git sha in version strings
  * Write and read more complex git sha info
- Changes from 0.10.2
  * Remove all 2.7 filtering
  * Stop filtering out argparse
  * Remove mirror testing from the integration script
- Changes from 0.10.1
  * Prefix git suffixes with + instead of
- fix Sphinx config.init_values fallout
- add update-alternatives
- remove outdated patches
  * 0001-use-get_boolean_option-for-warnerrors.patch
  * 0001-Allow-overwriting-sphinx-builder-list-from-command-l.patch
- Add pbr-0.10.8-fix-sphinx-init_values.patch
- put docs in its own package
* Fri Oct 24 2014 toddrme2178@gmail.com
- Add python-pip from requires to buildrequires
* Thu Aug 28 2014 dmueller@suse.com
- add 0001-Allow-overwriting-sphinx-builder-list-from-command-l.patch
  0001-use-get_boolean_option-for-warnerrors.patch
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Sat Jul 26 2014 tbechtold@suse.com
- Update BuildRequires according to test-requirements.txt
- Update to version 0.10.0
  * Remove all 2.7 filtering
  * Stop filtering out argparse
  * Remove mirror testing from the integration script
  0.9.0
  * Allow examining parsing exceptions
  * Update integration script for Apache 2.4
  * Restore Monkeypatched Distribution Instance
  * Register testr as a distutil entry point
  * Check for git before querying it for a version
  * Allow _run_cmd to run commands in any directory
  * Make setUp fail if sdist fails
  * Permit pre-release versions with git metadata
  * Un-nest some sections of code
  0.8.2
  * Remove --use-mailmap as it's not needed
  * Fix typos in docs
  0.8.1
  * pbr/testr_command.py: Add logging
  * Documentation updates
  * Fixed a typo in the documentation
  * Make source configurable when using --coverage
  * README.rst: tweaks
  * Format autoindex.rst file properly
  * make pbr use hacking directly
* Fri Mar 28 2014 speilicke@suse.com
- Update to version 0.8.0:
  * Use unicode_literals import instead of u'unicode' notation
  * Remove pip version specifier
  * Make tools/integration.sh take a branch
  * Fixes blocking issue on Windows
* Mon Mar 24 2014 dmueller@suse.com
- update to 0.7.0:
  * No changes, just use the released tarball which has
  the right version (that others are checking for)
* Tue Mar 18 2014 speilicke@suse.com
- Update to version pbr-0.6.14.g6ffff7c:
  * Factor run_cmd out of the base class
  * Return the real class in VersionInfo __repr__
  * Fix up some docstrings
  * Init sphinx config values before accessing them
  * Remove copyright from empty files
  * Declare support for Python versions in setup.cfg
  * Updated from global requirements
  * Remove unused _parse_mailmap()
  * Add support for python 3-<3.3
  * Remove tox locale overrides
  * Do not force log verbosity level to info
  0.6
  * package: read a specific Python version requirement file
- Fix dependencies
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Tue Feb  4 2014 dmueller@suse.com
- update to 0.6:
  * package: read a specific Python version requirement file
  * Fix typos in documents
  * Pin sphinx to <1.2
  * Build mirror using proper requirements
  * Use wheels for installation
  * show diff between pip installed packages and requirements
  * Enable wheel processing in the tests
  * Clean up integration script
  * Let git do mailmap mapping for us
  * Make ChangeLog more condensed
  * Make sphinx builders configurable in LocalBuildDoc
  * Serve local mirror using apache
  * Bump the development status classifier
  * Support building wheels (PEP-427)
  * Ignore jenkins@openstack.org in authors building
  * Communicate to user when we skip a requirement
  * Base python 2.7 skip list on parsed names
  * Link to the documentation in the readme
  * Avoid using 'which' executable for finding git
  * Add wheel mirror structure awareness
  * Remove pip as an argument from mkvenv
  * Use pypi-mirror instead of jeepyb
* Thu Jan  9 2014 speilicke@suse.com
- Update to version 0.5.23.36.g00fbbd1:
- Install from tarballs.openstack.org (rather than PyPI) and use _service file
* Mon Nov 25 2013 speilicke@suse.com
- Update dependencies
- Rename build-conditional to "test", avoid clash with Cloud:OpenStack:Master's
  "tests" build-conditional. We've got other issues here
- Add rpmlintrc, we have some C files as part of the testsuite
* Thu Oct 31 2013 dmueller@suse.com
- update to 0.5.23:
  * Use dev based release versioning
* Thu Aug  8 2013 speilicke@suse.com
- Update to version 0.5.21:
  + Replace setuptools_git with a smarter approach
* Mon Aug  5 2013 speilicke@suse.com
- Add python-pip requirement
* Sun Aug  4 2013 dmueller@suse.com
- update to 0.5.20:
  * Add support for globbing in data files
  * Stop trying to install old pip and setuptools
* Thu Jul 11 2013 dmueller@suse.com
- update to 0.5.18:
  * support python setup.py test
  * various python 3.x compat fixes
* Thu Jul  4 2013 speilicke@suse.com
- Introduce a build conditional for running tests to break build cycle
  with python-oslo.config
* Tue Jul  2 2013 dmueller@suse.com
- update description
* Wed Jun 26 2013 cdenicolo@suse.com
- license update: Apache-2.0
  license SUSE-Xano license not found in package. See LICENSE file.
* Wed Jun 26 2013 dmueller@suse.com
- remove python-discover dependency for newer distros
* Fri Jun 21 2013 dmueller@suse.com
- update to 0.5.17:
  * Remove dependency on distribute
  * Fix pip invocation for old versions of pip.
- remove 0001-Use-pip-instead-of-easy_install-for-installation.patch
- remove 0001-Skip-git-checkout-related-tests-when-.git-is-missing.patch
* Mon Jun 10 2013 dmueller@suse.com
- add 0001-Use-pip-instead-of-easy_install-for-installation.patch
* Mon Jun 10 2013 dmueller@suse.com
- update to 0.5.14:
  * Remove jinja pin.
  * Explicitly install install_requires.
  * More python3 compatibility.
  * Fix tox.ini to not reference deleted testenv
  * Fix doc autoindexing.
  * Add missing files to the tarball.
- add 0001-Skip-git-checkout-related-tests-when-.git-is-missing.patch
* Mon May 27 2013 dmueller@suse.com
- update to 0.5.10:
  + Default to single-version-externally-managed
  + Add config for skipping authors and changelog.
  + Update to d2to1 0.2.10.
* Tue May  7 2013 speilicke@suse.com
- Buildrequire python-python-mimeparse and use testr instead of nosetests.
  The pbr testsuite needs some proper setup to pass successfully.
* Thu May  2 2013 speilicke@suse.com
- Initial version
